Clazz.declarePackage("javajs.api");
(function(){
var c$ = Clazz.declareInterface(javajs.api, "GenericCifDataParser");
})();
;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
